Arrow

Struct Arrow 

pub struct Arrow { /* private fields */ }
Arrow middleware.

Provides data to position an inner element of the floating element so that it appears centered to the reference element.

See the Rust Floating UI book for more documentation.

Implementations

Source

impl Arrow

pub fn new(options: ArrowOptions) -> Self