pub struct Arrow { /* private fields */ }Expand description
Arrow middleware.
Provides data to position an inner element of the floating element so that it appears centered to the reference element.
See the Rust Floating UI book for more documentation.
Implementations